#!/usr/bin/env python

import sys
import os
import getopt
import pwd
import subprocess

import app.util
from svn import core, repos, fs
from ctfdb import ctfdb
from app import adapter_svn, vc

# Global config object and site paths.
cfg = app.util.getRuntimeConfiguration()
runtime_dir = cfg.get("RUNTIME_DIR")

#TODO: Enable logger

class CVS2SVN:

    def __init__(self):
        self.repo_name = None
        self.repos_root = None
        self.svn_repos = None
        self.cvs_integ_name = None
        self.svn_integ_name = None
        self.svn_repo_name = None

    def get_repo_path(self, db, repo_path_query):
        recs = db.executeQuery(repo_path_query)
        if not len(recs):
            self.printMessage("error", "Repository Not Found!...")
            sys.exit()
        elif len(recs) > 1:
            self.printMessage("error", "More than one repo found!...")
            sys.exit()
        return recs

    def get_cvs_repo_path(self,db):
        #Get cvs repository patch from query
        cvs_repo_path_query = """select s.repository_path from scm_repository \
s, external_system e where s.system_id=e.id and e.title='%s' and \
e.adapter_name like 'CVS%%' and s.id in ( select id from folder where id \
like 'reps%%' and title = '%s')""" %(self.cvs_integ_name, self.repo_name)

        recs = self.get_repo_path(db, cvs_repo_path_query)
        return recs[0][0]

    def installHookScripts(self, db):
        # Install pre-commit, post-commit and pre-revprop-change hook scripts
        runtimeDir = self.cfg.get('RUNTIME_DIR')
        sfPropertiesPath = os.path.join(runtimeDir, 'conf', 'sourceforge.properties')
        pythonWrapper = self.cfg.get('PYTHON_WRAPPER')
        sourceforgeHome = self.cfg.get('SOURCEFORGE_HOME')
        # Get external system id
        systemId_query = """select id from external_system where title = '%s' \
""" % self.svn_integ_name
        result = db.executeQuery(systemId_query)
        if not result:
            self.printMessage("error", "Unable to get external system id!...")
            sys.exit()
        systemId = result[0][0]
        repositorydir = os.path.join(self.svnroot, self.svn_repo_name)
        shebangLine = "#!/bin/sh\n"
        sfPrefix = "# BEGIN_SOURCEFORGE_SECTION - Do not remove these lines\n"
        sfSuffix = "# END SOURCEFORGE SECTION\n"
        self.printMessage("info", "Installing hook scripts for converted \
subversion repository...")
        # Create REPO_HOME/hooks/pre-commit that calls SOURCEFORGE_HOME/integration/pre-commit.py 
        preCommitFile = os.path.join(repositorydir, 'hooks', 'pre-commit')
        pre_fh = open(preCommitFile, 'a')
        pre_fh.write(shebangLine)
        pre_fh.write(sfPrefix)
        pre_fh.write("export SOURCEFORGE_PROPERTIES_PATH='")
        pre_fh.write(sfPropertiesPath)
        pre_fh.write("'\n")
        precommit_cmd = pythonWrapper + ' ' + os.path.join(sourceforgeHome, \
'integration', 'pre-commit.py') + " " + "\"$1\" \"$2\" " + systemId
        pre_fh.write(precommit_cmd)
        pre_fh.write("\n")
        pre_fh.write(sfSuffix)
        pre_fh.close()
        # Create REPO_HOME/hooks/post-commit that calls SOURCEFORGE_HOME/integration/post-commit.py
        postCommitFile = os.path.join(repositorydir, 'hooks', 'post-commit')
        post_fh = open(postCommitFile, 'a')
        post_fh.write(shebangLine)
        post_fh.write(sfPrefix)
        post_fh.write("export SOURCEFORGE_PROPERTIES_PATH='")
        post_fh.write(sfPropertiesPath)
        post_fh.write("'\n")
        postcommit_cmd = pythonWrapper + ' ' + os.path.join(sourceforgeHome, \
'integration', 'post-commit.py') + " " + "\"$1\" \"$2\" " + systemId
        post_fh.write(postcommit_cmd)
        post_fh.write("\n")
        post_fh.write(sfSuffix)
        post_fh.close()
        # Create REPO_HOME/hooks/pre-revprop-change that calls SOURCEFORGE_HOME/integration/pre-revprop-change.py
        preRevpropFile = os.path.join(repositorydir, 'hooks', 'pre-revprop-change')
        prerev_fh = open(preRevpropFile, 'a')
        prerev_fh.write(shebangLine)
        prerev_fh.write(sfPrefix)
        prerev_fh.write("export SOURCEFORGE_PROPERTIES_PATH='")
        prerev_fh.write(sfPropertiesPath)
        prerev_fh.write("'\n")
        prerevprop_cmd = pythonWrapper + ' ' + os.path.join(sourceforgeHome, \
'integration', 'pre-revprop-change.py') + " " + "\"$1\" \"$2\" \"$3\" \"$4\" \
\"$5\" " + systemId
        prerev_fh.write(prerevprop_cmd)
        prerev_fh.write("\n")
        prerev_fh.write(sfSuffix)
        prerev_fh.close()
        # Set Only ReadWriteExecute UserPermissions for the hook scripts
        cmd = "chmod 700 " + "'" + preCommitFile  + "'" + ' ' + "'" + postCommitFile + "'" + ' ' + "'" + preRevpropFile + "'"
        try:
            os.system(cmd)
        except:
            self.printMessage("error", "Error occurred while setting \
permissions for hook scripts")
            sys.exit()
            
    def update_db(self, db):
        #Updating the CTF database with newly created repo details
        scm_query = """update scm_repository set system_id = ( select id \
from external_system where title = '%s' ), repository_path = '%s' where \
id = ( select id from scm_repository where system_id in (select id from \
external_system where title = '%s') and id in ( select id from folder where \
id like 'reps%%' and title = '%s') ) """%(self.svn_integ_name, self.svn_repos,\
self.cvs_integ_name, self.repo_name )

        self.printMessage("info", "Updating CTF...")
        try:
            db.dmlQuery(scm_query)
            db.commit()
        except:
            self.printMessage("error", "Error Occurred %s\nOperation Aborted!..." %sys.exc_info()[0])
            sys.exit()

    def fix_ownership(self, db):
        #Fixing ownership of created svn repo
        #svn_repo_path_query = """select s.repository_path from scm_repository \
#s,external_system e where s.system_id=e.id and e.title='%s' and s.id in \
#( select id from folder where id like 'reps%%' and title = '%s')""" \
#%(self.svn_integ_name, self.svn_repo_name)
        #recs = self.get_repo_path(db, svn_repo_path_query)
        httpdUser = self.cfg.get('HTTPD_USER')
        httpdGroup = self.cfg.get('HTTPD_GROUP')
        svn_repo_path = os.path.join(self.svnroot, self.svn_repo_name)
        try:
            chownCmd = "chown -RL %s:%s " %(httpdUser, httpdGroup)
            chownCmd = chownCmd + "'" + svn_repo_path + "'"
            os.system(chownCmd)
        except:
            self.printMessage("error", "Unable to fix permissions for \
converted svnrepo!...")
            sys.exit()

    def archive_cvs_repos(self, cvs_repos, destination):
        """Archive the converted CVS repository directory under 
        DATA_DIR/scm-archive/convertedrepositories/."""
        cvs_dir_name = os.path.basename(cvs_repos)
        try: 
            os.rename(cvs_repos, os.path.join(destination, cvs_dir_name))
        except:
            self.printMessage("error", "Unable to move converted repository \
to %s" %(destination))

    def printMessage(self, msgType, msgData):
        """Function for printing messages"""
        HEADER = '\033[95m'
        OK = '\033[92mSUCCESS: '
        WARNING = '\033[93mWARN: '
        FAIL = '\033[91mERROR: '
        INFO = '\033[0mINFO: '
        ENDC = '\033[0m'

        if msgType == "warn":
            print WARNING + msgData + ENDC
        elif msgType == "error":
            print
            print FAIL + msgData + ENDC
        elif msgType == "success":
            print
            print OK + msgData + ENDC
        elif msgType == "info":
            print
            print INFO + msgData + ENDC


    def printUsageAndExit(self, error=None, exit_code=0):
        print
        print "This script converts cvs repositories into svn repositories"
        print
        print "Valid options: "
        print "  -h | --help                    print this usage message & \
exit"
        print "  -c | --cvs-integration-name=   specify CVS integration name"

        print "  -s | --svn-integration-name=   specify SVN integration name"

        print "  -r | --cvs-repository-name=    specify CVS repository name"
        print "  -d | --dump-file=              /path/to/dumpfile"
        print "  -R | --svn-repository-name=    specify SVN repository name \
when there already exists a svn repo with the same name as CVS repo"
        print
        if error:
            print >> sys.stderr, error

        sys.exit(exit_code)

    def validate_integration(self, db, integration_name):
       #Check if the integration name passed is valid
       integration_query = """select id from external_system where title='%s'\
       """ %(integration_name)
       recs = db.executeQuery(integration_query)
       if not len(recs):
           self.printMessage("error", "Integration - %s not found!..." %(integration_name))
           sys.exit()

    def main(self, argv):

        self.cfg = app.util.getRuntimeConfiguration()

        try:
            opts, args = getopt.getopt(argv, "hc:s:r:d:R:", ["help",
                              "cvs-integration-name=", "svn-integration-name=",
                              "cvs-repository-name=", "dump-file=",
                              "svn-repository-name="])
        except getopt.GetoptError, exc:
            self.printUsageAndExit("Getopt Error:%s\n" % exc, 1)
        for opt, value in opts:
            if opt in ("-h", "--help"):
                self.printUsageAndExit()
            if opt in ("-c", "--cvs-integration-name"):
                self.cvs_integ_name = value
            if opt in ("-s", "--svn-integration-name"):
                self.svn_integ_name = value
            if opt in ("-r", "--cvs-repository-name"):
                self.repo_name = value
            if opt in ("-d", "--dump-file"):
                self.dumpfile_path = value
            if opt in ("-R", "--svn-repository-name"):               
                # When -R option is used all other 4 options are mandatory
                if(len(opts)<4):
                   print
                   self.printMessage("error", "--cvs-integration-name, \
--svn-integration-name and --cvs-repository-name are mandatory")
                   self.printUsageAndExit("Invalid number of arguments", 1)
                self.svn_repo_name = value
            else:
                self.svn_repo_name = self.repo_name

        if(len(opts)<3):
            print
            self.printMessage("error", "--cvs-integration-name, \
--svn-integration-name and --cvs-repository-name are mandatory")
            self.printUsageAndExit("Invalid number of arguments", 1)

        db = ctfdb(self.cfg)
        #Check if the integrations are valid
        self.validate_integration(db, self.cvs_integ_name)
        self.validate_integration(db, self.svn_integ_name)
        
        self.svnroot = self.cfg.get('SUBVERSION_REPOSITORY_BASE')
        self.svn_repos = os.path.join(self.svnroot, self.svn_repo_name)
    
        print "#"*10, "Initializing cvs2svn", "#"*10

        self.svnadmin = self.cfg.get('SVNADMIN_BINARY')
        self.fstype = self.cfg.get('SUBVERSION_FSTYPE')

        current_dir = os.getcwd()
        # Change to /tmp directory to avoid 'permission denied' errors
        # while creating dump file (raised from cvs2svn_lib/main.py)
        os.chdir('/tmp')

        #Get cvs repository path
        cvs_repo = self.get_cvs_repo_path(db)
        # Install hook scripts, update database and fix ownership
        self.installHookScripts(db)
        self.update_db(db)
        self.fix_ownership(db)
        #Archive the converted cvs repository
        scm_archive = self.cfg.get('SCM_REPOSITORY_ARCHIVE')
        cvs_dest = os.path.join(scm_archive, 'convertedrepositories')
        if not os.path.isdir(cvs_dest):
            os.makedirs(cvs_dest) 
        self.printMessage("info", "Archiving the old CVS repository (to '%s')..." % (cvs_dest))
        self.archive_cvs_repos(cvs_repo, cvs_dest)
        print "\n","#"*10, "Successfully Completed", "#"*10


if __name__ == '__main__':
    os.environ['HOME'] = pwd.getpwuid(os.getuid())[5]
    cvs2svn = CVS2SVN()
    cvs2svn.main(sys.argv[1:])
